@@ -152,7 +152,7 @@ pdConstruct.pdMat <-
     } else {
       if (inherits(form, "formula")) {
         namesForm <- Names(asOneSidedFormula(form), data)
-        namesForm1 <- NULL
+##        namesForm1 <- NULL
       } else {
         stop("\"form\" can only be a formula or a list of formulae")
       }
@@ -224,7 +224,7 @@ pdMatrix.pdMat <-
 ###*# Methods for standard generics
 
 as.matrix.pdMat <-
-  function(x) pdMatrix(x)
+  function(x, ...) pdMatrix(x)
 
 coef.pdMat <-
   function(object, unconstrained = TRUE, ...)
@@ -1404,12 +1404,12 @@ corMatrix.pdIdent <-
   if (is.null(Ncol <- attr(object, "ncol"))) {
     stop(paste("Cannot extract the matrix with uninitialized dimensions"))
   }
-  val <- diag(Ncol)
+  val <- diag(nrow = Ncol)
   attr(val, "stdDev") <- rep(exp(as.vector(object)), Ncol)
   if (length(nm <- Names(object)) == 0) {
-    nm <- paste("V", 1:len, sep = "")
-    dimnames(val) <- list(nm, nm)
+    nm <- paste("V", 1:Ncol, sep = "")
   }
+  dimnames(val) <- list(nm, nm)
   names(attr(val, "stdDev")) <- nm
   val
 }
